@@ -13,9 +13,10 @@ from trexmodel.utils.model.model_util import create_db_client
 from flask.json import jsonify
 from datetime import datetime
 from trexapi.decorators.api_decorators import auth_token_required,\
-    outlet_key_required
+    outlet_key_required, test_session_expired
 from trexlib.utils.string_util import is_not_empty
-from trexmodel.models.datastore.customer_models import Customer
+from trexmodel.models.datastore.customer_models import Customer,\
+    CustomerMembership, CustomerTierMembership
 from trexmodel.models.datastore.user_models import User
 from trexadmin.libs.http import create_rest_message
 from trexadmin.libs.http import StatusCode
@@ -24,7 +25,6 @@ from trexmodel.models.datastore.merchant_models import Outlet,\
 from trexapi.forms.customer_api_forms import CustomerDetailsNewForm, CustomerDetailsUpdateForm,\
     CustomerSearchForm
 from werkzeug.datastructures import ImmutableMultiDict
-import gettext
 from trexapi.controllers.user_api_routes import user_details_dict
 from trexmodel.models.datastore.transaction_models import CustomerTransaction
 from trexapi.utils.api_helpers import get_logged_in_api_username
@@ -34,6 +34,9 @@ from trexapi.utils.reward_transaction_helper import revert_redemption,\
     revert_transaction
 from trexanalytics.bigquery_upstream_data_config import create_merchant_registered_customer_upstream_for_merchant,\
     create_registered_customer_upstream_for_system
+from trexmodel.models.datastore.membership_models import MerchantMembership,\
+    MerchantTierMembership
+from flask_babel import gettext
 
 logger = logging.getLogger('api')
 
@@ -121,10 +124,11 @@ def create_customer():
                         logger.debug('Valid granted outlet key for merchant acct')
                                                     
                         if is_email_used:
-                            created_customer = Customer.get_by_email(email)
-                            
-                        elif is_mobile_phone_used:
-                            created_customer = Customer.get_by_mobile_phone(mobile_phone)
+                            created_customer = Customer.get_by_email(email, merchant_acct=merchant_acct)
+                        
+                        if created_customer is None:    
+                            if is_mobile_phone_used:
+                                created_customer = Customer.get_by_mobile_phone(mobile_phone, merchant_acct=merchant_acct)
                         
                         if is_email_used or is_mobile_phone_used:
                             if created_customer is None:
@@ -380,7 +384,7 @@ def update_customer(customer_key):
                     else:
                         return create_rest_message(status_code=StatusCode.OK)
                 else:
-                    return create_rest_message(gettext('Customer is not exis'), status_code=StatusCode.BAD_REQUEST)
+                    return create_rest_message(gettext('Customer is not exist'), status_code=StatusCode.BAD_REQUEST)
             
         else:
             logger.warn('customer registration input is invalid')
@@ -412,8 +416,128 @@ def delete_customer(ref_code):
         return create_rest_message(status_code=StatusCode.BAD_REQUEST)        
 
 
+@customer_api_bp.route('/register-as-customer', methods=['POST'])
+@auth_token_required
+def register_user_as_customer():
+    user_data_in_json           = request.get_json()
+    reference_code              = user_data_in_json.get('reference_code')
+    
+    logger.debug('register_user_as_customer: user_data_in_json=%s', user_data_in_json)
+    
+    try:
+        if is_not_empty(reference_code):
+            logger.debug('customer registration input is valid')
+            db_client = create_db_client(caller_info="register_user_as_customer")
+            
+            created_customer        = None
+            existing_user_acct      = None
+            is_email_used           = False
+            is_mobile_phone_used    = False
+            merchant_act_key        = None
+            
+            merchant_acct           = None
+            
+            outlet_key  = request.headers.get('x-outlet-key')
+            acct_id     = request.headers.get('x-acct-id')
+            
+            logger.debug('register_user_as_customer: outlet_key=%s', outlet_key)
+            logger.debug('register_user_as_customer: acct_id=%s', acct_id)
+            logger.debug('register_user_as_customer: reference_code=%s', reference_code)
+            
+            with db_client.context():
+                existing_user_acct  = User.get_by_reference_code(reference_code)
+                
+                logger.debug('register_user_as_customer: existing_user_acct=%s', existing_user_acct)
+                
+                if existing_user_acct:
+                    
+                    outlet              = Outlet.fetch(outlet_key)
+                        
+                    if outlet:
+                        merchant_acct       = outlet.merchant_acct_entity
+                        merchant_act_key    = outlet.merchant_acct_key  
+                        logger.debug('Valid granted outlet key for merchant acct')
+                        
+                        created_customer = Customer.get_by_reference_code(reference_code, merchant_acct)
+                         
+                        logger.debug('register_user_as_customer: created_customer=%s', created_customer) 
+                         
+                        if created_customer is None:
+                            
+                            
+                            email           = existing_user_acct.email
+                            mobile_phone    = existing_user_acct.mobile_phone
+                            
+                            logger.debug('email=%s', email)
+                            logger.debug('mobile_phone=%s', mobile_phone)
+                            
+                            checking_customer = Customer.get_by_email(email, merchant_acct=merchant_acct) 
+                            
+                            if checking_customer:
+                                is_email_used = True
+                            else:
+                                if is_not_empty(mobile_phone):
+                                    checking_customer = Customer.get_by_mobile_phone(mobile_phone, merchant_acct=merchant_acct)
+                                    if checking_customer:
+                                        is_mobile_phone_used = True
+                            
+                            logger.debug('is_email_used=%s', is_email_used)
+                            logger.debug('is_mobile_phone_used=%s', is_mobile_phone_used)
+                            
+                            if is_email_used == False and is_mobile_phone_used == False:
+                            
+                                created_customer = Customer.create_from_user(outlet, existing_user_acct)
+                                
+                                create_merchant_registered_customer_upstream_for_merchant(created_customer)
+                                create_registered_customer_upstream_for_system(created_customer)
+                        
+                            
+                        logger.debug('created_customer=%s', created_customer)
+                        
+                    else:
+                        logger.warn('Invalid granted outlet key or merchant account id')
+                
+                if created_customer:
+                    
+                    
+                    
+                    response_data = {
+                                    'customer_key'              : created_customer.key_in_str,
+                                    'registered_datetime'       : created_customer.registered_datetime.strftime("%d-%m-%Y %H:%M:%S"),
+                                    'reference_code'            : created_customer.reference_code,
+                                    'merchant_account_key'      : merchant_act_key,
+                                    'company_name'              : merchant_acct.company_name,
+                                    'outlet_key'                : outlet_key,  
+                                    #'user_details'              : user_details_dict(existing_user_acct),
+                                    }
+                    
+                    response_data.update(user_details_dict(existing_user_acct))
+                    
+                    logger.debug('register_user_as_customer debug: response_data=%s', response_data)
+                    
+                    return create_rest_message(status_code=StatusCode.OK, **response_data)
+                    
+                else:
+                    if is_email_used==True:
+                        return create_rest_message('Email have been taken', status_code=StatusCode.BAD_REQUEST)
+                    
+                    elif is_mobile_phone_used==True:
+                        return create_rest_message('Mobile phone have been taken', status_code=StatusCode.BAD_REQUEST)
+                    else:
+                        return create_rest_message('Failed to register customer', status_code=StatusCode.BAD_REQUEST)
+            
+        else:
+            logger.warn('customer registration input is invalid')
+            
+            return create_rest_message("Missing register customer input data", status_code=StatusCode.BAD_REQUEST)
+    except:
+        logger.error('Fail to register customer due to %s', get_tracelog())
+        
+        return create_rest_message(status_code=StatusCode.BAD_REQUEST)
+
 @customer_api_bp.route('/search/<limit>', methods=['POST'])
-#@auth_token_required
+@auth_token_required
+#@test_session_expired
 def search_customer(limit):
     
     search_member_data_in_json   = request.get_json()
@@ -423,6 +547,7 @@ def search_customer(limit):
     
     db_client = create_db_client(caller_info="search_customer")
     customer_list = []
+    
     if search_customer_form.validate():
         name                        = search_customer_form.name.data
         mobile_phone                = search_customer_form.mobile_phone.data
@@ -468,10 +593,79 @@ def search_customer(limit):
         #return create_rest_message(status_code=StatusCode.OK, customer_list=customer_list)
         return jsonify(customer_list)
     else:
-        return create_rest_message(gettext('Invalid input'), status_code=StatusCode.BAD_REQUEST)
+        error_message = search_customer_form.create_rest_return_error_message()
+        return create_rest_message(error_message, status_code=StatusCode.BAD_REQUEST)
+        #return create_rest_message(gettext('Invalid input'), status_code=StatusCode.BAD_REQUEST)
+        #return create_rest_message('Invalid input', status_code=StatusCode.BAD_REQUEST)
+
+@customer_api_bp.route('/reference-code/<reference_code>/list-membership', methods=['GET'])
+@auth_token_required
+#@test_session_expired
+def list_customer_membership(reference_code):
+    if is_not_empty(reference_code):
+        acct_id   = request.headers.get('x-acct-id')
+        db_client = create_db_client(caller_info="list_customer_membership")
+        customer_membership_final_list = []
+        
+        logger.debug('reference_code=%s', reference_code)
+        
+        with db_client.context():
+            merchant_acct = MerchantAcct.fetch(acct_id)
+            customer = Customer.get_by_reference_code(reference_code, merchant_acct)
+            customer_memberhips_list        = CustomerMembership.list_active_by_customer(customer)
+            customer_tier_memberhips_list   = CustomerTierMembership.list_active_by_customer(customer)
+            
+            logger.debug('customer=%s', customer)
+            
+            logger.debug('customer_memberhips_list=%s', customer_memberhips_list)
+            
+            if is_not_empty(customer_memberhips_list):
+                merchant_memberships_list = MerchantMembership.list_by_merchant_acct(merchant_acct)
+                
+                for cm in customer_memberhips_list:
+                    for mm in merchant_memberships_list:
+                        if mm.key_in_str == cm.merchant_membership_key:
+                            customer_membership_data = {
+                                                            'key'           : cm.key_in_str,
+                                                            'label'         : mm.label,
+                                                            'entitled_date' : cm.entitled_date.strftime('%d-%m-%Y'),
+                                                            'expiry_date'   : cm.expiry_date.strftime('%d-%m-%Y'),
+                                                            'is_tier'       : False,
+                                                            }
+                            
+                            if cm.renewed_date is not None:
+                                customer_membership_data['renewed_date'] = cm.renewed_date.strftime('%d-%m-%Y'),
+                            
+                            customer_membership_final_list.append(customer_membership_data)
+                            break
+                        
+            if is_not_empty(customer_tier_memberhips_list):
+                merchant_tier_memberships_list = MerchantTierMembership.list_by_merchant_acct(merchant_acct)
+                
+                for cm in customer_tier_memberhips_list:
+                    for mm in merchant_tier_memberships_list:
+                        if mm.key_in_str == cm.merchant_tier_membership_key:
+                            customer_membership_data = {
+                                                            'key'           : cm.key_in_str,
+                                                            'label'         : mm.label,
+                                                            'entitled_date' : cm.entitled_date.strftime('%d-%m-%Y'),
+                                                            'expiry_date'   : cm.expiry_date.strftime('%d-%m-%Y'),
+                                                            'is_tier'       : True,
+                                                            }
+                            
+                            customer_membership_final_list.append(customer_membership_data)
+                            break            
+        
+    
+        return jsonify(customer_membership_final_list)
+    else:
+        return create_rest_message(status_code=StatusCode.BAD_REQUEST)    
+                
+
 
 @customer_api_bp.route('/reference-code/<reference_code>/transaction/limit/<limit>', methods=['GET'])
 @auth_token_required
+#@test_session_expired
 def list_customer_transaction(reference_code, limit):
     
     logger.debug('reference_code=%s', reference_code)
@@ -492,6 +686,7 @@ def list_customer_transaction(reference_code, limit):
                                #'transact_outlet_details', 
                                'transact_datetime', 'created_datetime',  'transact_outlet_key', 'is_revert', 'reverted_datetime',
                                'transact_by_username', 'is_reward_redeemed', 'is_sales_transaction', 'allow_to_revert',
+                               'is_membership_purchase', 'purchased_merchant_membership_key', 'is_membership_renew',
                                ]
             with db_client.context():
                 result       = CustomerTransaction.list_customer_transaction(customer, limit=limit_int)
@@ -544,6 +739,7 @@ def __revert_customer_transaction(customer_transction, reverted_by, reverted_dat
     
 @customer_api_bp.route('/reference-code/<reference_code>/redemption/limit/<limit>', methods=['GET'])
 @auth_token_required
+#@test_session_expired
 def list_customer_redemption(reference_code, limit):
     
     logger.debug('reference_code=%s', reference_code)
