@@ -17,6 +17,7 @@ from trexlib.utils.common.common_util import sort_list
 from firebase_admin import firestore
 from datetime import datetime
 from trexapi.conf import API_ERR_CODE_INVALID_ACTIVATION_CODE
+from trexadmin import conf
 
 
 #logger = logging.getLogger('api')
@@ -61,7 +62,9 @@ def get_device_setting(activation_code, device_id=None):
                 logger.info('device activation code is valid');
                 device_setting_details = None
                 with db_client.context():
-                    device_setting.activate(device_id)
+                    if device_setting.is_test_setting==False:
+                        device_setting.activate(device_id)
+                    
                     device_setting_details                              = merchant_helpers.construct_setting_by_outlet(device_setting.assigned_outlet_entity, device_setting=device_setting) 
                     
                     device_setting_details['logo_image_url']            = url_for('system_bp.merchant_logo_image_url', merchant_act_key=device_setting_details.get('account_id'))
@@ -135,21 +138,25 @@ def updateActivationAndGetDeviceSetting(activation_code, device_id):
             
             is_valid = False
             device_setting_details = None
+            is_production = conf.IS_PRODUCTION
             
             with db_client.context():
                 device_setting = LoyaltyDeviceSetting.get_by_activation_code(activation_code)
-                if device_setting.activated:
-                    if device_setting.device_id == device_id:
+                if device_setting.is_test_setting==False:
+                    if device_setting.activated:
+                        if device_setting.device_id == device_id:
+                            is_valid = True
+                        
+                    else:
                         is_valid = True
-                    
+                        device_setting.activate(device_id, activated=is_production)
                 else:
                     is_valid = True
-                    device_setting.activate(device_id)
-            
+                
                 if is_valid:    
                     device_setting_details                                 = merchant_helpers.construct_setting_by_outlet(device_setting.assigned_outlet_entity, device_setting=device_setting)
                     #pos_setting_details['logo_image_url']               = url_for('system_bp.merchant_logo_image_url', merchant_act_key=pos_setting_details.get('account_id'))
-            
+                
             if is_valid:
                 
                 logger.debug('device_setting_details=%s', device_setting_details);
@@ -253,16 +260,6 @@ def version_sync():
         version =  {
                                
                                 'setting':[
-                                            {
-                                                "table_name": "setting",
-                                                "version" : 2,
-                                                "script": "ALTER TABLE setting ADD COLUMN device_id TEXT",
-                                            },
-                                            {
-                                                "table_name": "setting",
-                                                "version" : 3,
-                                                "script": "ALTER TABLE setting ADD COLUMN membership_configurations TEXT",
-                                            }
                                                
                                         ],
                                        
