@@ -19,7 +19,8 @@ from trexmodel.models import merchant_helpers
 from trexmodel.models.datastore.transaction_models import CustomerTransaction
 from flask.json import jsonify
 from trexadmin.libs.http import create_rest_message, StatusCode
-from trexapi.decorators.api_decorators import auth_token_required
+from trexapi.decorators.api_decorators import auth_token_required,\
+    test_session_expired
 from trexapi.utils.api_helpers import get_logged_in_api_username
 from flask_babel import gettext
 from trexapi.utils.reward_transaction_helper import revert_redemption,\
@@ -36,7 +37,7 @@ outlet_api_bp = Blueprint('outlet_api_bp', __name__,
 
 logger = logging.getLogger('debug')
 
-@outlet_api_bp.route('/details/<outlet_key>', methods=['GET'])
+@outlet_api_bp.route('/<outlet_key>/details', methods=['GET'])
 def read_outlet(outlet_key):
     
     outlet_details          = None
@@ -95,6 +96,7 @@ def read_outlet(outlet_key):
         
 @outlet_api_bp.route('/outlet-key/<outlet_key>/sales-transaction/limit/<limit>', methods=['GET'])
 @auth_token_required
+#@test_session_expired
 def list_outlet_transaction(outlet_key, limit):
     db_client = create_db_client(caller_info="list_outlet_transaction")
     transactions_list = []
@@ -110,6 +112,7 @@ def list_outlet_transaction(outlet_key, limit):
                            'entitled_reward_summary', 'entitled_voucher_summary', 'entitled_prepaid_summary', 'transact_customer_acct',
                            'transact_datetime', 'created_datetime',  'transact_outlet_key', 'is_revert', 'reverted_datetime',
                            'transact_by_username', 'is_reward_redeemed', 'is_sales_transaction', 'allow_to_revert',
+                           'is_membership_purchase', 'purchased_merchant_membership_key', 'is_membership_renew',
                            ]
         with db_client.context():
             result       = CustomerTransaction.list_outlet_transaction(outlet, limit=limit_int)
@@ -123,7 +126,8 @@ def list_outlet_transaction(outlet_key, limit):
 
 
 @outlet_api_bp.route('/outlet-key/<outlet_key>/redemption/limit/<limit>', methods=['GET'])
-#@auth_token_required
+@auth_token_required
+#@test_session_expired
 def list_outlet_redemption(outlet_key, limit):
     db_client = create_db_client(caller_info="list_outlet_transaction")
     redemptions_list = []
@@ -172,7 +176,8 @@ def revert_outlet_transaction(outlet_key, transaction_id):
                     reverted_datetime_utc   = datetime.utcnow()
                     __revert_customer_transaction(customer_transactionn, reverted_by, reverted_datetime=reverted_datetime_utc)
                 
-                return create_rest_message(status_code=StatusCode.OK, reverted_datetime = customer_transactionn.reverted_datetime.strftime('%d-%m-%Y %H:%M:%S'))
+                return create_rest_message(status_code=StatusCode.OK, reverted_datetime = datetime.now().strftime('%d-%m-%Y %H:%M:%S'))
+                #return create_rest_message(status_code=StatusCode.OK)
             else:
                 return create_rest_message(gettext('Not allow to revert from different outlet'), status_code=StatusCode.BAD_REQUEST)
         else:    
