@@ -25,7 +25,7 @@ from trexapi.forms.reward_api_forms import GiveRewardTransactionForm, RedeemRewa
     PrepaidTopupForm, PrepaidRedeemForm, PointRedeemForm
 from werkzeug.datastructures import ImmutableMultiDict
 from trexmodel.models.datastore.transaction_models import CustomerTransaction
-from trexapi.utils.reward_transaction_helper import create_sales_transaction,\
+from trexapi.utils.reward_transaction_helper import create_reward_transaction,\
     redeem_reward_transaction, create_topup_prepaid_transaction
 from trexapi.utils.api_helpers import get_logged_in_api_username
 from trexmodel.models.datastore.voucher_models import MerchantVoucher
@@ -113,6 +113,7 @@ def give_reward(reference_code):
             invoice_id          = reward_transaction_form.invoice_id.data
             remarks             = reward_transaction_form.remarks.data
             invoice_details     = transaction_data_in_json.get('invoice_details')
+            
             transact_datetime   = None
             
             
@@ -127,7 +128,7 @@ def give_reward(reference_code):
             logger.debug('remarks=%s', remarks)
             logger.debug('invoice_details=%s', invoice_details)
             
-            db_client = create_db_client(caller_info="givea_reward")
+            db_client = create_db_client(caller_info="give_reward")
             
             check_transaction_by_invoice_id = None
             
@@ -141,6 +142,8 @@ def give_reward(reference_code):
                 transact_datetime_in_gmt    = reward_transaction_form.transact_datetime.data
                 merchant_username           = get_logged_in_api_username()
                 
+                logger.debug('transact_datetime_in_gmt=%s', transact_datetime_in_gmt)
+                
                 if merchant_username:
                     try:
                         with db_client.context():
@@ -162,7 +165,7 @@ def give_reward(reference_code):
                             
                             logger.debug('going to call give_reward_transaction')
                             
-                            customer_transaction = create_sales_transaction(customer, 
+                            customer_transaction = create_reward_transaction(customer, 
                                                                             transact_outlet     = transact_outlet, 
                                                                             sales_amount        = sales_amount,
                                                                             tax_amount          = tax_amount,
