@@ -9,7 +9,8 @@ import logging
 from trexlib.utils.log_util import get_tracelog
 from trexmodel.utils.model.model_util import create_db_client
 from datetime import datetime, timedelta
-from trexapi.decorators.api_decorators import auth_token_required
+from trexapi.decorators.api_decorators import auth_token_required,\
+    user_auth_token_required
 from trexlib.utils.string_util import is_not_empty, is_empty
 from trexmodel.models.datastore.customer_models import Customer
 from trexadmin.libs.http import create_rest_message
@@ -29,6 +30,9 @@ from trexmodel import program_conf
 from trexapi import conf
 from trexmodel.models.datastore.user_models import User
 from flask.json import jsonify
+from trexmodel.models.datastore.model_decorators import model_transactional
+from trexmodel.models.datastore.reward_model_helpers import check_redeem_voucher_is_valid
+from flask_babel import gettext
 
 logger = logging.getLogger('api')
 
@@ -45,7 +49,7 @@ def ping():
     return create_rest_message('Pong', status_code=StatusCode.OK)
 
 @voucher_api_bp.route('/voucher/<redeem_code>/details', methods=['GET'])
-#@auth_token_required
+@auth_token_required
 def read_voucher(redeem_code):
     if is_not_empty(redeem_code):
         voucher_details = None
@@ -132,10 +136,9 @@ def redeem_voucher():
             
             
             
-            already_redeemed_list                               = []
-            to_redeem_voucher_keys_list                         = []
-            customer                                            = None
-            found_not_valid_redeem_code_list                    = []
+            to_redeem_voucher_keys_list                             = []
+            customer                                                = None
+            customer_vouchers_list                                  = []
             
             with db_client.context():
                 merchant_username       = get_logged_in_api_username()
@@ -143,50 +146,55 @@ def redeem_voucher():
                 
                 for redeem_code in redeem_code_list:
                     customer_voucher    = CustomerEntitledVoucher.get_by_redeem_code(redeem_code)
-                    if customer_voucher:
-                        if customer_voucher.is_redeemed:
-                            already_redeemed_list.append(redeem_code)
-                        else:
-                            to_redeem_voucher_keys_list.append(customer_voucher.key_in_str)
-                            if customer is None:
-                                customer = customer_voucher.entitled_customer_entity
+                    customer_vouchers_list.append(customer_voucher)
+                    to_redeem_voucher_keys_list.append(customer_voucher.key_in_str)
+                    if customer is None:
+                        customer = customer_voucher.entitled_customer_entity
                     else:
-                        found_not_valid_redeem_code_list.append(redeem_code)
-            
-            if found_not_valid_redeem_code_list:
-                return create_rest_message("Voucher ({redeem_codes_list}) is not valid".format(redeem_codes_list=",".join(found_not_valid_redeem_code_list)), 
-                                           status_code=StatusCode.BAD_REQUEST)            
-            
-            elif already_redeemed_list:
-                return create_rest_message("Voucher ({redeem_codes_list}) have been redeemed before,  thus it is not allow to redeem again".format(redeem_codes_list=",".join(already_redeemed_list)), 
-                                           status_code=StatusCode.BAD_REQUEST)
-            else:
-                if to_redeem_voucher_keys_list:
-                    with db_client.context():
-                        if to_redeem_voucher_keys_list:
-                            
-                            customer_redemption = CustomerRedemption.create(customer, program_conf.REWARD_FORMAT_VOUCHER , redeemed_by_outlet,
-                                      redeemed_amount               = 1,            
-                                      redeemed_voucher_keys_list    = to_redeem_voucher_keys_list, 
-                                      redeemed_by                   = redeemed_by, 
-                                      redeemed_datetime             = redeemed_datetime,
-                                      invoice_id                    = invoice_id,
-                                      remarks                       = remarks,
-                                      )
-                            
-                            logger.debug('customer_redemption=%s', customer_redemption)
+                        checking_customer = customer_voucher.entitled_customer_entity
+                        if checking_customer.key_in_str!=customer.key_in_str:
+                            return create_rest_message(gettext('Voucher must from same customer'), status_code=StatusCode.BAD_REQUEST)
                             
+                
+            try:
+                with db_client.context():
+                    check_redeem_voucher_is_valid(customer, customer_vouchers_list, redeem_datetime=redeem_datetime)
+            except Exception as error:
+                logger.error('Failed due to %s', get_tracelog())
+                return create_rest_message(str(error), status_code=StatusCode.BAD_REQUEST)
             
-                        if customer_redemption:
-                            create_merchant_customer_redemption_upstream_for_merchant(customer_redemption, streamed_datetime=redeemed_datetime)
-                    
-                    if customer_redemption:        
-                        return create_rest_message(transaction_id = customer_redemption.transaction_id, status_code=StatusCode.OK)
-                    else:
-                        return create_rest_message("Failed to redeem voucher", status_code=StatusCode.BAD_REQUEST)
+            @model_transactional(desc='redeem_voucher')
+            def __start_transaction_for_redeem_voucher():
+                
+                customer_redemption = CustomerRedemption.create(customer, program_conf.REWARD_FORMAT_VOUCHER , redeemed_by_outlet,
+                                  redeemed_amount               = 1,            
+                                  redeemed_voucher_keys_list    = to_redeem_voucher_keys_list, 
+                                  redeemed_by                   = redeemed_by, 
+                                  redeemed_datetime             = redeemed_datetime,
+                                  invoice_id                    = invoice_id,
+                                  remarks                       = remarks,
+                                  )
+                return customer_redemption
+            
+            if to_redeem_voucher_keys_list:
+                with db_client.context():
+                    if to_redeem_voucher_keys_list:
+                        
+                        customer_redemption = __start_transaction_for_redeem_voucher()
+                        
+                        logger.debug('customer_redemption=%s', customer_redemption)
+                        
+        
+                    if customer_redemption:
+                        create_merchant_customer_redemption_upstream_for_merchant(customer_redemption, streamed_datetime=redeemed_datetime)
+                
+                if customer_redemption:        
+                    return create_rest_message(transaction_id = customer_redemption.transaction_id, status_code=StatusCode.OK)
                 else:
-                    return create_rest_message('Voucher redeem code is required', status_code=StatusCode.BAD_REQUEST)
-    
+                    return create_rest_message("Failed to redeem voucher", status_code=StatusCode.BAD_REQUEST)
+            else:
+                return create_rest_message('Voucher redeem code is required', status_code=StatusCode.BAD_REQUEST)
+                
     else:
         logger.warn('redeem voucher data input is invalid')
         error_message = redeem_voucher_form.create_rest_return_error_message()
@@ -205,7 +213,7 @@ def remove_voucher(redeem_code):
         #redeem_code         = remove_voucher_data_in_json.get('redeem_code')
         remarks             = remove_voucher_form.remarks.data
         remove_datetime     = remove_voucher_form.remove_datetime.data
-        merchant_acct       = None
+        #merchant_acct       = None
         
         logger.debug('redeem_code=%s', redeem_code)
         logger.debug('remove_datetime=%s', remove_datetime)
@@ -292,4 +300,25 @@ def list_entitled_voucher(reference_code):
     else:
         logger.warn('reset_password_post: email is invalid')
         return create_rest_message(status_code=StatusCode.BAD_REQUEST)       
-    
\ No newline at end of file
+    
+@voucher_api_bp.route('/voucher/<redeem_code>/remove-by-user', methods=['DELETE'])
+@user_auth_token_required
+def remove_user_voucher(redeem_code):
+    if is_not_empty(redeem_code):
+        reference_code = request.headers.get('x-reference-code')
+        logger.debug('reference_code=%s', reference_code)
+        db_client = create_db_client(caller_info="remove_user_voucher")
+        with db_client.context():
+            customer_voucher    = CustomerEntitledVoucher.get_by_redeem_code(redeem_code)
+            '''
+            if customer_voucher: 
+                customer_voucher.remove()  
+                customer = customer_voucher.entitled_customer_acct
+                customer.update_after_removed_voucher(customer_voucher)
+            '''    
+        if customer_voucher:        
+            return create_rest_message(status_code=StatusCode.BAD_REQUEST)
+        else:
+            return create_rest_message('Invalid voucher redeem code', status_code=StatusCode.BAD_REQUEST)
+    else:
+        return create_rest_message('Missing voucher redeem code', status_code=StatusCode.BAD_REQUEST)
