@@ -9,10 +9,19 @@ from trexlib.utils.string_util import is_not_empty
 from trexlib.utils.crypto_util import decrypt_json
 import logging
 from datetime import datetime
+from trexlib.utils.log_util import get_tracelog
+from trexadmin.libs.http import create_rest_message, StatusCode
 
 logger = logging.getLogger('decorator')
 #logger = logging.getLogger('debug')
 
+def test_session_expired(f):
+    @wraps(f)
+    def decorated_function(*args, **kwargs):
+        return ("Authenticated token is expired", 401)
+    
+    return decorated_function
+
 def auth_token_required(f):
     @wraps(f)
     def decorated_function(*args, **kwargs):
@@ -66,14 +75,16 @@ def user_auth_token_required(f):
         logger.debug('user_auth_token=%s', user_auth_token)
         
         if is_not_empty(user_auth_token):
+            logger.debug('user_auth_token is not empty, going to decrypt it')
             try:
                 auth_details_json = decrypt_json(user_auth_token)
+                logger.debug('auth_details_json=%s', auth_details_json)
+                
             except:
+                logger.error('Failed due to %s', get_tracelog())
                 return ("Authenticated token is not valid", 401)
             
-             
             
-            logger.debug('auth_details_json=%s', auth_details_json)
             
             if auth_details_json:
                 expiry_datetime                 = auth_details_json.get('expiry_datetime')
@@ -90,11 +101,14 @@ def user_auth_token_required(f):
                     else:
                         logger.debug('auth token is not logger valid')
                         
-                        return ("Authenticated token is expired", 401)
+                        #return ("Authenticated token is expired", 401)
+                        return create_rest_message('Authenticated token is expired', status_code=StatusCode.UNAUTHORIZED,)
             else:
-                return ("Authenticated token is invalid", 401)    
+                #return ("Authenticated token is invalid", 401)    
+                return create_rest_message('Authenticated token is invalid', status_code=StatusCode.UNAUTHORIZED,)
         
-        return ("Authenticated token is required", 401)
+        #return ("Authenticated token is required", 401)
+        return create_rest_message('Authenticated token is required', status_code=StatusCode.UNAUTHORIZED,)
 
     return decorated_function
 
@@ -113,3 +127,19 @@ def outlet_key_required(f):
         return ("Outlet Key is required", 401)
 
     return decorated_function
+
+def merchant_key_required(f):
+    @wraps(f)
+    def decorated_function(*args, **kwargs):
+        acct_id = request.headers.get('x-acct-id')
+            
+        logger.debug('acct_id=%s', acct_id)
+        
+        if is_not_empty(acct_id):
+            logger.debug('Going to execute')
+            return f(*args, **kwargs)
+            
+        
+        return ("Merchant account id is required", 401)
+
+    return decorated_function
