@@ -3,17 +3,13 @@ from trexadmin.forms.base_forms import ValidationBaseForm
 from trexadmin.libs.wtforms import validators as custom_validator
 from flask_babel import gettext
 from datetime import date
+from wtforms.fields.core import FloatField
 
-class UserRegistrationForm(ValidationBaseForm):
+class UserMinForm(ValidationBaseForm):
     name                = StringField(gettext('Name'), validators=[
                                         validators.InputRequired(gettext('Name is required')),
                                         validators.Length(min=3, max=300, message='Name length must be within 3 and 300 characters'),
                                         
-                                        ]
-                                        )
-    email               = StringField('Email Address', validators=[
-                                        validators.Email(gettext("Please enter valid email address.")),
-                                        validators.InputRequired(gettext('Email is required')),
                                         ]
                                         )
     mobile_phone        = StringField('Mobile Phone', validators=[
@@ -31,31 +27,49 @@ class UserRegistrationForm(ValidationBaseForm):
                                         ]
                                         )
     
+    
+    
+class UserRegistrationForm(UserMinForm):
+    email               = StringField('Email Address', validators=[
+                                        validators.Email(gettext("Please enter valid email address.")),
+                                        validators.InputRequired(gettext('Email is required')),
+                                        ]
+                                        )
+    
     password            = StringField(gettext('Password'), validators=[
                                         validators.InputRequired(gettext('Password is required')),
                                         
                                         ]
-                                        )
+                                        )  
     
-class UserDetailsForm(UserRegistrationForm):
+class UserUpdateForm(UserMinForm):
+    reference_code      = StringField('User Reference Code', validators=[
+                                        validators.InputRequired(gettext('User Reference Code is required')),
+                                        ]
+                                        )      
     
-    gender              = StringField(gettext('Gender'), [
-                                        validators.Optional(),
-                                        validators.Length(min=1, max=1, message=gettext('Gender value is either m or f')),
-                                        
+class OutletReviewsForm(ValidationBaseForm):
+    outlet_key               = StringField('Outlet Key', validators=[
+                                        validators.InputRequired(gettext('Outlet key is required')),
                                         ]
                                         )
     
-    birth_date          = DateField('Date of Birth', format='%d/%m/%Y', validators=[
-                                            validators.Optional(),
-                                        ])
+    food_score               = FloatField('Food Score', validators=[
+                                        validators.InputRequired(gettext('Food score is required')),
+                                        ]
+                                        )
     
-    mobile_phone        = StringField('Mobile Phone', validators=[
-                                        custom_validator.RequiredIfOtherFieldEmpty(
-                                                        ['email'],
-                                                        message=gettext("Either email or mobile phone is required"),
-                                                        
-                                                        ),
-                                        
+    service_score               = FloatField('Service Score', validators=[
+                                        validators.InputRequired(gettext('Service score is required')),
+                                        ]
+                                        )
+    
+    ambience_score          = FloatField('Ambience Score', validators=[
+                                        validators.InputRequired(gettext('Ambience score is required')),
+                                        ]
+                                        )
+    
+    value_for_money_score   = FloatField('Value for money Score', validators=[
+                                        validators.InputRequired(gettext('Value for money score is required')),
                                         ]
                                         )    
\ No newline at end of file
